'use strict';

const chalk = require('chalk');
const Reporter = require('./Reporter');
const Validator = require('./Validator');
const Config = require('./Config');

class PermissionsPlugin {

  /**
   * Creates an instance of PermissionsPlugin.
   * @param {Object} bitbucketApiClient BitbucketApiClient object
   * @memberof PermissionsPlugin
   */
  constructor(bitbucketApiClient) {
    this.permissionConfig = Config.getConfig();
    this.bitbucketApiClient = bitbucketApiClient;

    this.validator = new Validator(bitbucketApiClient);
  }

  execute() {
    return new Promise((resolve, reject) => {
      let promises = [];

      for (let project in this.permissionConfig) {
        promises.push(this.validator.validateProject(this.permissionConfig[project]));
      }

      Promise.all(promises).then((results) => {
        Reporter.write(this.validator.getErrors());
        console.log(chalk.green.bold('Permissions Plugin Completed Successfully'));
        resolve();
      }).catch((error) => {
        Reporter.write(this.validator.getErrors());
        reject();
      });
    });
  }
}

module.exports = PermissionsPlugin;
