'use strict';

const chalk = require('chalk');
const moment = require('moment');

class PullRequest {
  constructor(project, repo, pullRequest) {
    this._project = project;
    this._repo = repo;
    this._id = pullRequest.id;
    this._title = pullRequest.title;
    this._author = pullRequest.author.name.displayName;
    this._createdDate = moment(pullRequest.createdDate).format('YYYY-MM-DD');
    this._age = moment(pullRequest.updatedDate).fromNow();
    this._fromBranchName = pullRequest.fromRef.displayId;
    this._toBranchName = pullRequest.toRef.displayId;
    this._message = '';
    this._toString();
  }

  _toString() {
    let message = chalk.red.bold('Stale pr detected \n');
    message += '\t' + chalk.magenta.bold('Project: ') + chalk.magenta(this._project) + '\n';
    message += '\t' + chalk.cyan.bold('Repo: ') + chalk.cyan(this._repo) + '\n';
    message += '\t' + chalk.blue.bold('ID: ') + chalk.blue(this._id) + '\n';
    message += '\t' + chalk.yellow.bold('Title: ') + chalk.yellow(this._title) + '\n';
    message += '\t' + chalk.magenta.bold('Author: ') + chalk.magenta(this._author) + '\n';
    message += '\t' + chalk.cyan(this._fromBranchName) + chalk.cyan.bold(' --> ') + chalk.cyan(this._toBranchName) + '\n';
    message += '\t' + chalk.blue.bold('Last Updated: ') + chalk.blue(this._age) + '\n';
    message += '\t' + chalk.yellow.bold('Created On: ') + chalk.yellow(this._createdDate) + '\n';

    this._message = message;
  }

  getMessage() {
    return this._message;
  }
}

module.exports = PullRequest;
