'use strict';

const chalk = require('chalk');
const Reporter = require('./Reporter');
const Auditor = require('./Auditor');
const Config = require('./Config');

class StalePrs {

  /**
   * Creates an instance of StalePrs.
   * @param {Object} bitbucketApiClient BitbucketApiClient object
   * @memberof StalePrs
   */
  constructor(bitbucketApiClient) {
    this.stalePrsConfig = Config.getConfig();
    this.bitbucketApiClient = bitbucketApiClient;

    this.auditor = new Auditor(bitbucketApiClient, this.stalePrsConfig.definitionOfStale);
  }

  execute() {
    return new Promise((resolve, reject) => {
      const promises = [];

      for (const project in this.stalePrsConfig.projects) {
        promises.push(this.auditor.auditProject(this.stalePrsConfig.projects[project]));
      }

      Promise.all(promises).then((results) => {
        Reporter.write(this.auditor.getStalePrs());
        console.log(chalk.green.bold('Stale PRs Plugin Completed Successfully'));
        resolve();
      }).catch((error) => {
        console.log(error);
        reject();
      });
    });
  }
}

module.exports = StalePrs;
